@@ -43,6 +43,8 @@
 #include <KWaylandServer/display.h>
 #endif
 
+Q_LOGGING_CATEGORY(BLUR_DEBUG, "debug_k_blur", QtCriticalMsg);
+
 static const int RR = 18;    // radius of rounded corner
 static const int DOCK_WINDTH_JUDGE = 800;    // differentiate tooltip on dock
 static const int NEAR_PLANE = -1000;
@@ -79,6 +81,8 @@ BlurEffect::BlurEffect(QObject *, const QVariantList &)
     connect(effects, &EffectsHandler::windowDeleted, this, &BlurEffect::slotWindowDeleted);
     connect(effects, &EffectsHandler::propertyNotify, this, &BlurEffect::slotPropertyNotify);
     connect(effects, &EffectsHandler::screenGeometryChanged, this, &BlurEffect::slotScreenGeometryChanged);
+    connect(effects, &EffectsHandler::windowGeometryShapeChanged, this, &BlurEffect::slotWindowGeometryShapeChanged);
+
 #if defined(KWIN_VERSION) && KWIN_VERSION >= KWIN_VERSION_CHECK(5, 11, 0, 0)
     connect(effects, &EffectsHandler::xcbConnectionChanged, this,
         [this] {
@@ -160,7 +164,7 @@ void BlurEffect::updateTexture()
         }
 
         if (colorEncoding == GL_SRGB) {
-            textureFormat = GL_SRGB8_ALPHA8;
+            //textureFormat = GL_SRGB8_ALPHA8;
         }
     }
 
@@ -319,6 +323,8 @@ QRegion rounded(QRegion region, int r)
 
 void BlurEffect::updateBlurRegion(EffectWindow *w) const
 {
+    qCDebug(BLUR_DEBUG)<<"className:"<< w->windowClass();
+
     QRegion region;
     QByteArray value;
 
@@ -359,29 +365,14 @@ void BlurEffect::updateBlurRegion(EffectWindow *w) const
         // being set, and being set to an empty region.
         w->setData(WindowBlurBehindRole, 1);
     } else {
-        if (effects->waylandDisplay()) {
-            auto wndClassName = w->windowClass();
-            auto wndType = w->windowType();
-            if (wndClassName.contains("dde-launcher")
-                    || (wndClassName.contains("dde-clipboard"))
-                    || (wndClassName.contains("dde-osd"))  //notification, cap
-                    || (w->isDock() && w->geometry().width() > DOCK_WINDTH_JUDGE)
-                    || w->isPopupWindow()
-                    || (wndClassName.contains("deepin-app-store"))
-                    || (wndClassName.contains("dde-network-dialog"))
-                    || (wndClassName.contains("dde-grand-search"))) {
-                w->setData(WindowBlurBehindRole, 1);
-            } else {
-                w->setData(WindowBlurBehindRole, region);
-            }
-        } else {
-            w->setData(WindowBlurBehindRole, region);
-        }
+        w->setData(WindowBlurBehindRole, region);
     }
 }
 
 void BlurEffect::slotWindowAdded(EffectWindow *w)
 {
+    if(w) qCDebug(BLUR_DEBUG)<<"className:"<< w->windowClass();
+
     KWaylandServer::SurfaceInterface *surf = w->surface();
 
     if (surf) {
@@ -406,6 +397,8 @@ void BlurEffect::slotWindowDeleted(EffectWindow *w)
     if (it == windowBlurChangedConnections.end()) {
         return;
     }
+    qCDebug(BLUR_DEBUG)<<"className:"<< w->windowClass();
+
     disconnect(*it);
     windowBlurChangedConnections.erase(it);
 }
@@ -413,6 +406,7 @@ void BlurEffect::slotWindowDeleted(EffectWindow *w)
 void BlurEffect::slotPropertyNotify(EffectWindow *w, long atom)
 {
     if (w && atom == net_wm_blur_region && net_wm_blur_region != XCB_ATOM_NONE) {
+        qCDebug(BLUR_DEBUG)<<"className:"<< w->windowClass();
         updateBlurRegion(w);
     }
 }
@@ -493,26 +487,8 @@ QRegion BlurEffect::blurRegion(const EffectWindow *w) const
                 region -= w->decorationInnerRect();
             }
 
-            if (effects->waylandDisplay()) {
-                if ( w->windowClass().contains("dde-clipboard")
-                        || w->windowClass().contains("dde-osd")
-                        || w->windowClass().contains("DeepinAI")
-                        || w->windowClass().contains("dde-launcher")) {
-                    region = rounded(w->shape(), RR);
-                } else if (w->isDock() && w->geometry().width() > DOCK_WINDTH_JUDGE) {
-                    region = rounded(w->shape(), RR);
-                } else if (w->isPopupWindow()) {
-                    region = rounded(w->shape(), RR);
-                } else if (w->isTooltip()) {
-                    region = rounded(w->shape(), RR);
-                } else {
-                    region |= appRegion.translated(w->contentsRect().topLeft()) &
-                              w->decorationInnerRect();
-                }
-            } else {
-                region |= appRegion.translated(w->contentsRect().topLeft()) &
+            region |= appRegion.translated(w->contentsRect().topLeft()) &
                           w->decorationInnerRect();
-            }
         } else {
             // An empty region means that the blur effect should be enabled
             // for the whole window.
@@ -523,20 +499,6 @@ QRegion BlurEffect::blurRegion(const EffectWindow *w) const
         // the effect behind the decoration.
         region = w->shape();
         region -= w->decorationInnerRect();
-    } else {
-        if (effects->waylandDisplay()) {
-            if (w->isDock() && w->geometry().width() > DOCK_WINDTH_JUDGE) {
-                region = rounded(w->shape(), RR);
-            } else if (w->isTooltip()) {
-                region = rounded(w->shape(), RR);
-            } else if (w->windowClass().contains("dde-launcher")) {
-                region = rounded(w->shape(), RR);
-            } else if (w->windowClass().contains("Deepin")) {
-                region = rounded(w->shape(), RR);
-            } else if (w->isPopupWindow()) {
-                region = rounded(w->shape(), RR);
-            }
-        }
     }
 
     return region;
@@ -719,14 +681,7 @@ void BlurEffect::paintWindow(EffectWindow *w, int mask, QRegion region, WindowPa
         }
 
         if (!shape.isEmpty()) {
-            if (effects->waylandDisplay()) {
-                GLint vp[4];
-                glGetIntegerv(GL_VIEWPORT, &vp[0]);
-                doBlur(shape, screen, data.opacity(), data.screenProjectionMatrix(), w->isDock(), w->geometry());
-                glViewport(vp[0], vp[1], vp[2], vp[3]);
-            } else {
-                doBlur(shape, screen, data.opacity(), data.screenProjectionMatrix(), w->isDock(), w->geometry());
-            }
+            doBlur(shape, screen, data.opacity(), data.screenProjectionMatrix(), w->isDock(), w->geometry());
         }
     }
 
@@ -740,7 +695,7 @@ void BlurEffect::paintEffectFrame(EffectFrame *frame, const QRegion &region, dou
 void BlurEffect::paintEffectFrame(EffectFrame *frame, QRegion region, double opacity, double frameOpacity)
 #endif
 {
-    const QRect screen = effects->virtualScreenGeometry();
+    const QRect screen = GLRenderTarget::virtualScreenGeometry();
     bool valid = m_renderTargetsValid && m_shader && m_shader->isValid();
 
     QRegion shape = frame->geometry().adjusted(-borderSize, -borderSize, borderSize, borderSize) & screen;
@@ -851,25 +806,8 @@ void BlurEffect::doBlur(const QRegion& shape, const QRect& screen, const float o
         glBlendFunc(GL_CONSTANT_ALPHA, GL_ONE_MINUS_CONSTANT_ALPHA);
     }
 
-    if (effects->waylandDisplay()) {
-        int x = screen.x();
-        int y = screen.y();
-        int w = screen.width();
-        int h = screen.height();
-        float cx = x + w / 2;
-        float cy = y + h / 2;
-
-        QMatrix4x4 projection, view;
-        projection.ortho(-w / 2, w / 2, h / 2, -h / 2, NEAR_PLANE, FAR_PLANE);
-        view.lookAt(QVector3D(cx, cy, EYE_POSZ), QVector3D(cx, cy, 0), QVector3D(0, 1, 0));
-        QMatrix4x4 combinedMatrix = projection * view;
-
-        doSaturation(vbo, blurRectCount * (m_downSampleIterations + 1), shape.rectCount() * 6, 2.0, combinedMatrix);
-        upscaleRenderToScreen(vbo, blurRectCount * (m_downSampleIterations + 1), shape.rectCount() * 6, combinedMatrix, windowRect.topLeft());
-    } else {
-        doSaturation(vbo, blurRectCount * (m_downSampleIterations + 1), shape.rectCount() * 6, 2.0, screenProjection);
-        upscaleRenderToScreen(vbo, blurRectCount * (m_downSampleIterations + 1), shape.rectCount() * 6, screenProjection, windowRect.topLeft());
-    }
+    doSaturation(vbo, blurRectCount * (m_downSampleIterations + 1), shape.rectCount() * 6, 2.0, screenProjection, screen);
+    upscaleRenderToScreen(vbo, blurRectCount * (m_downSampleIterations + 1), shape.rectCount() * 6, screenProjection, windowRect.topLeft());
 
     if (useSRGB) {
         glDisable(GL_FRAMEBUFFER_SRGB);
@@ -882,8 +820,10 @@ void BlurEffect::doBlur(const QRegion& shape, const QRect& screen, const float o
     vbo->unbindArrays();
 }
 
-void BlurEffect::doSaturation(GLVertexBuffer* vbo, int start, int blurRectCount, float sat, QMatrix4x4 screenProjection)
+void BlurEffect::doSaturation(GLVertexBuffer* vbo, int start, int blurRectCount, float sat, QMatrix4x4 screenProjection, const QRect &screen)
 {
+    const int xTranslate = - screen.x();
+    const int yTranslate = - (effects->virtualScreenSize().height() - screen.height() - screen.y());
     auto& renderTexture = m_renderTextures[m_downSampleIterations+1];
 
     QMatrix4x4 modelViewProjectionMatrix;
@@ -899,6 +839,7 @@ void BlurEffect::doSaturation(GLVertexBuffer* vbo, int start, int blurRectCount,
     //Render to the screen
     vbo->draw(GL_TRIANGLES, start, blurRectCount);
     GLRenderTarget::popRenderTarget();
+    glViewport(xTranslate, yTranslate, effects->virtualScreenSize().width(), effects->virtualScreenSize().height());
 
     m_shader->unbind();
 }
@@ -1004,3 +945,12 @@ void BlurEffect::copyScreenSampleTexture(GLVertexBuffer *vbo, int blurRectCount,
 
     m_shader->unbind();
 }
+
+void BlurEffect::slotWindowGeometryShapeChanged(KWin::EffectWindow *w, const QRect &old)
+{
+    if(w) {
+        qCDebug(BLUR_DEBUG)<<"className:"<< w->windowClass()<< " old rect:"<< old;
+        updateBlurRegion(w);
+    }
+
+}
